from django.contrib import admin

from oscarbot.models import Bot


@admin.register(Bot)
class BotAdmin(admin.ModelAdmin):
    list_display = ('t_id', 'username', 'name')
    # readonly_fields = ('token', )



import json

import requests
from django.conf import settings
from django.core.management import BaseCommand

from oscarbot.services import get_bot_model
from oscarbot.views import handle_content


class Command(BaseCommand):

    def handle(self, *args, **options):
        bot_model = get_bot_model()
        bot = bot_model.objects.all().first()
        offset = 0
        try:
            while True:
                url = f'{settings.TELEGRAM_URL}{bot.token}/getUpdates?offset={offset}'
                response = requests.get(url, timeout=60)
                total_message = b''
                for message in response:
                    total_message += message
                body = total_message.decode('utf-8')
                body = body.replace('\n', '')
                content = json.loads(body)
                if len(content['result']) > 0:
                    offset = int(content['result'][0]['update_id']) + 1
                    if offset > 0:
                        handle_content(bot.token, content['result'][0])
        except KeyboardInterrupt:
            print('Exit bot server')



# Generated by Django 4.2.6 on 2024-01-14 14:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oscarbot', '0005_constructor'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='state_information',
            field=models.TextField(blank=True, null=True),
        ),
    ]



from oscarbot.menu import Menu
from oscarbot.models import User
from oscarbot.response import TGResponse
from oscarbot.services import get_bot_model


class QuickBot:

    def __init__(self, chat: object, message: str, token: str = None, menu: Menu = None):
        """
        Init QuickBot object for send message to Telegram user
        @param chat: user id, or username if this user in DB, can be oscarbot.models.User object
        @param message: text message
        @param token: bot token, default get first bot from DB
        @param menu: should be oscarbot.menu.Menu object
        """
        if token:
            self.token = token
        else:
            bot_model = get_bot_model()
            bot_object = bot_model.objects.all().first()
            if bot_object:
                self.token = bot_object.token

        if isinstance(chat, int):
            self.chat = chat
        elif isinstance(chat, str):
            chat_user = User.objects.filter(username=chat).first()
            if chat_user:
                self.chat = chat_user.t_id
        elif isinstance(chat, User):
            self.chat = chat.t_id

        self.message = message
        self.menu = menu

    def send(self):
        response = TGResponse(message=self.message, menu=self.menu)

        response.send(
            self.token,
            t_id=self.chat
        )



import json

from oscarbot.handler import BaseHandler
from django.http import HttpResponse
from django.views.decorators.csrf import csrf_exempt

from oscarbot.services import get_bot_model


@csrf_exempt
def bot_view(request, token):
    if request.method == 'POST':
        body = request.body.decode('utf-8')
        body = body.replace('\n', '')
        content = json.loads(body)
        return handle_content(token, content)


def handle_content(token, content):
    bot_model = get_bot_model()
    current_bot = bot_model.objects.filter(token=token).first()
    if current_bot:
        handler = BaseHandler(current_bot, content)
        tg_response = handler.handle()
        if tg_response:
            if tg_response.can_send():
                tg_response.send(token, handler.user)
            return HttpResponse("OK")
    else:
        raise RuntimeError('Failed to find bot')
